==> zrythm-0.6.039.tar.xz: zrythm-0.6.039/README.md <==
Zrythm
======

[![translated](https://hosted.weblate.org/widgets/zrythm/-/svg-badge.svg "Translation Status")](https://hosted.weblate.org/engage/zrythm/?utm_source=widget)

Zrythm is a highly automated Digital Audio Workstation (DAW) designed to be featureful and intuitive to use. Zrythm sets itself apart from other DAWs by allowing extensive automation via built-in LFOs and envelopes and intuitive MIDI or audio editing and arranging via clips.

In the usual Composing -> Mixing -> Mastering workflow, Zrythm puts the most focus on the Composing part. It allows musicians to quickly lay down and process their musical ideas without taking too much time for unnecessary work.

It is written in C and uses the GTK+3 toolkit, with bits and pieces taken from other programs like Ardour and Jalv.

More info at https://www.zrythm.org

# Current state

Zrythm is currently in alpha.
![screenshot 1](https://www.zrythm.org/static/images/may_28_2019.png)
![screenshot 2](https://www.zrythm.org/static/images/may_28_2019_2.png)

## Currently supported plugin protocols:
- LV2

## Building and Installation
See [INSTALL.md](INSTALL.md).

## Using
At the moment, Zrythm works with Jack (recommended) and ALSA.
For Jack setup instructions see
https://libremusicproduction.com/articles/demystifying-jack-%E2%80%93-beginners-guide-getting-started-jack

For more information see the [user manual](doc/user/README.md).

## Packaging
See [PACKAGING.md](PACKAGING.md).

## Contributing
For contributing guidelines see [CONTRIBUTING.md](CONTRIBUTING.md). Be sure to take a look at the
[Developer Docs](https://docs.zrythm.org)

For any bugs please raise an issue or join a
chatroom below

## Chatrooms
`#zrythm` channel on freenode (for Matrix users `#zrythmdaw:matrix.org`).

## Mailing lists
zrythm-dev@nongnu.org for developers, zrythm-user@nongnu.org for users

## Bug Tracker
https://savannah.nongnu.org/support/?group=zrythm

## Releases
https://savannah.nongnu.org/files/?group=zrythm

## License
Zrythm is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

Zrythm is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

The full text of the license can be found in the
[COPYING](COPYING) file.

For the copyright years, Zrythm uses a range (“2008-2010”) instead of
listing individual years (“2008, 2009, 2010”) if and only if every year
in the range, inclusive, is a “copyrightable” year that would be listed
individually.

Some files, where specified, are licensed under
different licenses.

## Support
We appreciate contributions of any size -- donations
enable us to spend more time working on the project,
and help cover our infrastructure expenses.

### Paypal
https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=LZWVK6228PQGE&source=url
### LiberaPay
https://liberapay.com/Zrythm/
### Bitcoin
bc1qjfyu2ruyfwv3r6u4hf2nvdh900djep2dlk746j

----

Copyright (C) 2018-2019 Alexandros Theodotou

Copying and distribution of this file, with or without modification,
are permitted in any medium without royalty provided the copyright
notice and this notice are preserved.  This file is offered as-is,
without any warranty.

==> zrythm-0.6.261.tar.xz: zrythm-0.6.261/README.md <==
Zrythm
======

[![translated](https://hosted.weblate.org/widgets/zrythm/-/svg-badge.svg "Translation Status")](https://hosted.weblate.org/engage/zrythm/?utm_source=widget)

Zrythm is a highly automated Digital Audio Workstation (DAW) designed to be featureful and intuitive to use. Zrythm sets itself apart from other DAWs by allowing extensive automation via built-in LFOs and envelopes and intuitive MIDI or audio editing and arranging via clips.

In the usual Composing -> Mixing -> Mastering workflow, Zrythm puts the most focus on the Composing part. It allows musicians to quickly lay down and process their musical ideas without taking too much time for unnecessary work.

It is written in C and uses the GTK+3 toolkit, with bits and pieces taken from other programs like Ardour and Jalv.

More info at https://www.zrythm.org

# Current state

Zrythm is currently in alpha.
![screenshot](https://www.zrythm.org/static/images/aug_22_2019.png)

## Currently supported plugin protocols:
- LV2

## Building and Installation
See [INSTALL.md](INSTALL.md).

## Using
At the moment, Zrythm works with Jack (recommended) and ALSA.
For Jack setup instructions see
https://libremusicproduction.com/articles/demystifying-jack-%E2%80%93-beginners-guide-getting-started-jack

For more information see the [user manual](doc/user/README.md).

## Packaging
See [PACKAGING.md](PACKAGING.md).

## Contributing
For contributing guidelines see [CONTRIBUTING.md](CONTRIBUTING.md). Be sure to take a look at the
[Developer Docs](https://docs.zrythm.org)

For any bugs please raise an issue or join a
chatroom below

## Chatrooms
`#zrythm` channel on freenode (for Matrix users `#zrythmdaw:matrix.org`).

## Mailing lists
zrythm-dev@nongnu.org for developers, zrythm-user@nongnu.org for users

## Bug Tracker
https://savannah.nongnu.org/support/?group=zrythm

## Releases
https://savannah.nongnu.org/files/?group=zrythm

## License
Zrythm is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

Zrythm is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

The full text of the license can be found in the
[COPYING](COPYING) file.

For the copyright years, Zrythm uses a range (“2008-2010”) instead of
listing individual years (“2008, 2009, 2010”) if and only if every year
in the range, inclusive, is a “copyrightable” year that would be listed
individually.

Some files, where specified, are licensed under
different licenses.

## Support
We appreciate contributions of any size -- donations
enable us to spend more time working on the project,
and help cover our infrastructure expenses.

### LiberaPay
https://liberapay.com/Zrythm/

----

Copyright (C) 2018-2019 Alexandros Theodotou

Copying and distribution of this file, with or without modification,
are permitted in any medium without royalty provided the copyright
notice and this notice are preserved.  This file is offered as-is,
without any warranty.
